==> huaweicloudsdkdrs-3.1.133-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/get_data_transformation_resp.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class GetDataTransformationResp:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_count': 'int',
        'filter_conditions': 'list[DataTransformationInfo]'
    }

    attribute_map = {
        'total_count': 'total_count',
        'filter_conditions': 'filter_conditions'
    }

    def __init__(self, total_count=None, filter_conditions=None):
        """GetDataTransformationResp

        The model defined in huaweicloud sdk

        :param total_count: 数据加工总数。
        :type total_count: int
        :param filter_conditions: 数据过滤配置信息。
        :type filter_conditions: list[:class:`huaweicloudsdkdrs.v3.DataTransformationInfo`]
        """
        
        

        self._total_count = None
        self._filter_conditions = None
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if filter_conditions is not None:
            self.filter_conditions = filter_conditions

    @property
    def total_count(self):
        """Gets the total_count of this GetDataTransformationResp.

        数据加工总数。

        :return: The total_count of this GetDataTransformationResp.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this GetDataTransformationResp.

        数据加工总数。

        :param total_count: The total_count of this GetDataTransformationResp.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def filter_conditions(self):
        """Gets the filter_conditions of this GetDataTransformationResp.

        数据过滤配置信息。

        :return: The filter_conditions of this GetDataTransformationResp.
        :rtype: list[:class:`huaweicloudsdkdrs.v3.DataTransformationInfo`]
        """
        return self._filter_conditions

    @filter_conditions.setter
    def filter_conditions(self, filter_conditions):
        """Sets the filter_conditions of this GetDataTransformationResp.

        数据过滤配置信息。

        :param filter_conditions: The filter_conditions of this GetDataTransformationResp.
        :type filter_conditions: list[:class:`huaweicloudsdkdrs.v3.DataTransformationInfo`]
        """
        self._filter_conditions = filter_conditions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetDataTransformationResp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.1.146-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/get_data_transformation_resp.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class GetDataTransformationResp:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_count': 'int',
        'filter_conditions': 'list[DataTransformationInfo]'
    }

    attribute_map = {
        'total_count': 'total_count',
        'filter_conditions': 'filter_conditions'
    }

    def __init__(self, total_count=None, filter_conditions=None):
        r"""GetDataTransformationResp

        The model defined in huaweicloud sdk

        :param total_count: 数据加工总数。
        :type total_count: int
        :param filter_conditions: 数据过滤配置信息。
        :type filter_conditions: list[:class:`huaweicloudsdkdrs.v3.DataTransformationInfo`]
        """
        
        

        self._total_count = None
        self._filter_conditions = None
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if filter_conditions is not None:
            self.filter_conditions = filter_conditions

    @property
    def total_count(self):
        r"""Gets the total_count of this GetDataTransformationResp.

        数据加工总数。

        :return: The total_count of this GetDataTransformationResp.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        r"""Sets the total_count of this GetDataTransformationResp.

        数据加工总数。

        :param total_count: The total_count of this GetDataTransformationResp.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def filter_conditions(self):
        r"""Gets the filter_conditions of this GetDataTransformationResp.

        数据过滤配置信息。

        :return: The filter_conditions of this GetDataTransformationResp.
        :rtype: list[:class:`huaweicloudsdkdrs.v3.DataTransformationInfo`]
        """
        return self._filter_conditions

    @filter_conditions.setter
    def filter_conditions(self, filter_conditions):
        r"""Sets the filter_conditions of this GetDataTransformationResp.

        数据过滤配置信息。

        :param filter_conditions: The filter_conditions of this GetDataTransformationResp.
        :type filter_conditions: list[:class:`huaweicloudsdkdrs.v3.DataTransformationInfo`]
        """
        self._filter_conditions = filter_conditions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetDataTransformationResp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
